==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/mixer/adapter/stackdriver/HttpRequestMappingFluentImpl.java <==
package me.snowdrop.istio.mixer.adapter.stackdriver;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class HttpRequestMappingFluentImpl<A extends HttpRequestMappingFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements HttpRequestMappingFluent<A>{

    private String latency;
    private String localIp;
    private String method;
    private String referer;
    private String remoteIp;
    private String requestSize;
    private String responseSize;
    private String status;
    private String url;
    private String userAgent;

    public HttpRequestMappingFluentImpl(){
    }
    public HttpRequestMappingFluentImpl(HttpRequestMapping instance){
            this.withLatency(instance.getLatency()); 
            this.withLocalIp(instance.getLocalIp()); 
            this.withMethod(instance.getMethod()); 
            this.withReferer(instance.getReferer()); 
            this.withRemoteIp(instance.getRemoteIp()); 
            this.withRequestSize(instance.getRequestSize()); 
            this.withResponseSize(instance.getResponseSize()); 
            this.withStatus(instance.getStatus()); 
            this.withUrl(instance.getUrl()); 
            this.withUserAgent(instance.getUserAgent()); 
    }

    public String getLatency(){
            return this.latency;
    }

    public A withLatency(String latency){
            this.latency=latency; return (A) this;
    }

    public Boolean hasLatency(){
            return this.latency != null;
    }

    public String getLocalIp(){
            return this.localIp;
    }

    public A withLocalIp(String localIp){
            this.localIp=localIp; return (A) this;
    }

    public Boolean hasLocalIp(){
            return this.localIp != null;
    }

    public String getMethod(){
            return this.method;
    }

    public A withMethod(String method){
            this.method=method; return (A) this;
    }

    public Boolean hasMethod(){
            return this.method != null;
    }

    public String getReferer(){
            return this.referer;
    }

    public A withReferer(String referer){
            this.referer=referer; return (A) this;
    }

    public Boolean hasReferer(){
            return this.referer != null;
    }

    public String getRemoteIp(){
            return this.remoteIp;
    }

    public A withRemoteIp(String remoteIp){
            this.remoteIp=remoteIp; return (A) this;
    }

    public Boolean hasRemoteIp(){
            return this.remoteIp != null;
    }

    public String getRequestSize(){
            return this.requestSize;
    }

    public A withRequestSize(String requestSize){
            this.requestSize=requestSize; return (A) this;
    }

    public Boolean hasRequestSize(){
            return this.requestSize != null;
    }

    public String getResponseSize(){
            return this.responseSize;
    }

    public A withResponseSize(String responseSize){
            this.responseSize=responseSize; return (A) this;
    }

    public Boolean hasResponseSize(){
            return this.responseSize != null;
    }

    public String getStatus(){
            return this.status;
    }

    public A withStatus(String status){
            this.status=status; return (A) this;
    }

    public Boolean hasStatus(){
            return this.status != null;
    }

    public String getUrl(){
            return this.url;
    }

    public A withUrl(String url){
            this.url=url; return (A) this;
    }

    public Boolean hasUrl(){
            return this.url != null;
    }

    public String getUserAgent(){
            return this.userAgent;
    }

    public A withUserAgent(String userAgent){
            this.userAgent=userAgent; return (A) this;
    }

    public Boolean hasUserAgent(){
            return this.userAgent != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            HttpRequestMappingFluentImpl that = (HttpRequestMappingFluentImpl) o;
            if (latency != null ? !latency.equals(that.latency) :that.latency != null) return false;
            if (localIp != null ? !localIp.equals(that.localIp) :that.localIp != null) return false;
            if (method != null ? !method.equals(that.method) :that.method != null) return false;
            if (referer != null ? !referer.equals(that.referer) :that.referer != null) return false;
            if (remoteIp != null ? !remoteIp.equals(that.remoteIp) :that.remoteIp != null) return false;
            if (requestSize != null ? !requestSize.equals(that.requestSize) :that.requestSize != null) return false;
            if (responseSize != null ? !responseSize.equals(that.responseSize) :that.responseSize != null) return false;
            if (status != null ? !status.equals(that.status) :that.status != null) return false;
            if (url != null ? !url.equals(that.url) :that.url != null) return false;
            if (userAgent != null ? !userAgent.equals(that.userAgent) :that.userAgent != null) return false;
            return true;
    }




}

==> istio-model-1.7.7.1-sources.jar: me/snowdrop/istio/mixer/adapter/stackdriver/HttpRequestMappingFluentImpl.java <==
package me.snowdrop.istio.mixer.adapter.stackdriver;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class HttpRequestMappingFluentImpl<A extends HttpRequestMappingFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements HttpRequestMappingFluent<A>{

    private String latency;
    private String localIp;
    private String method;
    private String referer;
    private String remoteIp;
    private String requestSize;
    private String responseSize;
    private String status;
    private String url;
    private String userAgent;

    public HttpRequestMappingFluentImpl(){
    }
    public HttpRequestMappingFluentImpl(HttpRequestMapping instance){
            this.withLatency(instance.getLatency()); 
            this.withLocalIp(instance.getLocalIp()); 
            this.withMethod(instance.getMethod()); 
            this.withReferer(instance.getReferer()); 
            this.withRemoteIp(instance.getRemoteIp()); 
            this.withRequestSize(instance.getRequestSize()); 
            this.withResponseSize(instance.getResponseSize()); 
            this.withStatus(instance.getStatus()); 
            this.withUrl(instance.getUrl()); 
            this.withUserAgent(instance.getUserAgent()); 
    }

    public String getLatency(){
            return this.latency;
    }

    public A withLatency(String latency){
            this.latency=latency; return (A) this;
    }

    public Boolean hasLatency(){
            return this.latency != null;
    }

    public A withNewLatency(String arg1){
            return (A)withLatency(new String(arg1));
    }

    public A withNewLatency(StringBuilder arg1){
            return (A)withLatency(new String(arg1));
    }

    public A withNewLatency(StringBuffer arg1){
            return (A)withLatency(new String(arg1));
    }

    public String getLocalIp(){
            return this.localIp;
    }

    public A withLocalIp(String localIp){
            this.localIp=localIp; return (A) this;
    }

    public Boolean hasLocalIp(){
            return this.localIp != null;
    }

    public A withNewLocalIp(String arg1){
            return (A)withLocalIp(new String(arg1));
    }

    public A withNewLocalIp(StringBuilder arg1){
            return (A)withLocalIp(new String(arg1));
    }

    public A withNewLocalIp(StringBuffer arg1){
            return (A)withLocalIp(new String(arg1));
    }

    public String getMethod(){
            return this.method;
    }

    public A withMethod(String method){
            this.method=method; return (A) this;
    }

    public Boolean hasMethod(){
            return this.method != null;
    }

    public A withNewMethod(String arg1){
            return (A)withMethod(new String(arg1));
    }

    public A withNewMethod(StringBuilder arg1){
            return (A)withMethod(new String(arg1));
    }

    public A withNewMethod(StringBuffer arg1){
            return (A)withMethod(new String(arg1));
    }

    public String getReferer(){
            return this.referer;
    }

    public A withReferer(String referer){
            this.referer=referer; return (A) this;
    }

    public Boolean hasReferer(){
            return this.referer != null;
    }

    public A withNewReferer(String arg1){
            return (A)withReferer(new String(arg1));
    }

    public A withNewReferer(StringBuilder arg1){
            return (A)withReferer(new String(arg1));
    }

    public A withNewReferer(StringBuffer arg1){
            return (A)withReferer(new String(arg1));
    }

    public String getRemoteIp(){
            return this.remoteIp;
    }

    public A withRemoteIp(String remoteIp){
            this.remoteIp=remoteIp; return (A) this;
    }

    public Boolean hasRemoteIp(){
            return this.remoteIp != null;
    }

    public A withNewRemoteIp(String arg1){
            return (A)withRemoteIp(new String(arg1));
    }

    public A withNewRemoteIp(StringBuilder arg1){
            return (A)withRemoteIp(new String(arg1));
    }

    public A withNewRemoteIp(StringBuffer arg1){
            return (A)withRemoteIp(new String(arg1));
    }

    public String getRequestSize(){
            return this.requestSize;
    }

    public A withRequestSize(String requestSize){
            this.requestSize=requestSize; return (A) this;
    }

    public Boolean hasRequestSize(){
            return this.requestSize != null;
    }

    public A withNewRequestSize(String arg1){
            return (A)withRequestSize(new String(arg1));
    }

    public A withNewRequestSize(StringBuilder arg1){
            return (A)withRequestSize(new String(arg1));
    }

    public A withNewRequestSize(StringBuffer arg1){
            return (A)withRequestSize(new String(arg1));
    }

    public String getResponseSize(){
            return this.responseSize;
    }

    public A withResponseSize(String responseSize){
            this.responseSize=responseSize; return (A) this;
    }

    public Boolean hasResponseSize(){
            return this.responseSize != null;
    }

    public A withNewResponseSize(String arg1){
            return (A)withResponseSize(new String(arg1));
    }

    public A withNewResponseSize(StringBuilder arg1){
            return (A)withResponseSize(new String(arg1));
    }

    public A withNewResponseSize(StringBuffer arg1){
            return (A)withResponseSize(new String(arg1));
    }

    public String getStatus(){
            return this.status;
    }

    public A withStatus(String status){
            this.status=status; return (A) this;
    }

    public Boolean hasStatus(){
            return this.status != null;
    }

    public A withNewStatus(String arg1){
            return (A)withStatus(new String(arg1));
    }

    public A withNewStatus(StringBuilder arg1){
            return (A)withStatus(new String(arg1));
    }

    public A withNewStatus(StringBuffer arg1){
            return (A)withStatus(new String(arg1));
    }

    public String getUrl(){
            return this.url;
    }

    public A withUrl(String url){
            this.url=url; return (A) this;
    }

    public Boolean hasUrl(){
            return this.url != null;
    }

    public A withNewUrl(String arg1){
            return (A)withUrl(new String(arg1));
    }

    public A withNewUrl(StringBuilder arg1){
            return (A)withUrl(new String(arg1));
    }

    public A withNewUrl(StringBuffer arg1){
            return (A)withUrl(new String(arg1));
    }

    public String getUserAgent(){
            return this.userAgent;
    }

    public A withUserAgent(String userAgent){
            this.userAgent=userAgent; return (A) this;
    }

    public Boolean hasUserAgent(){
            return this.userAgent != null;
    }

    public A withNewUserAgent(String arg1){
            return (A)withUserAgent(new String(arg1));
    }

    public A withNewUserAgent(StringBuilder arg1){
            return (A)withUserAgent(new String(arg1));
    }

    public A withNewUserAgent(StringBuffer arg1){
            return (A)withUserAgent(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            HttpRequestMappingFluentImpl that = (HttpRequestMappingFluentImpl) o;
            if (latency != null ? !latency.equals(that.latency) :that.latency != null) return false;
            if (localIp != null ? !localIp.equals(that.localIp) :that.localIp != null) return false;
            if (method != null ? !method.equals(that.method) :that.method != null) return false;
            if (referer != null ? !referer.equals(that.referer) :that.referer != null) return false;
            if (remoteIp != null ? !remoteIp.equals(that.remoteIp) :that.remoteIp != null) return false;
            if (requestSize != null ? !requestSize.equals(that.requestSize) :that.requestSize != null) return false;
            if (responseSize != null ? !responseSize.equals(that.responseSize) :that.responseSize != null) return false;
            if (status != null ? !status.equals(that.status) :that.status != null) return false;
            if (url != null ? !url.equals(that.url) :that.url != null) return false;
            if (userAgent != null ? !userAgent.equals(that.userAgent) :that.userAgent != null) return false;
            return true;
    }




}
